==> tensorflow_lattice-2.0.9-py2.py3-none-any.whl: tensorflow_lattice/__init__.py <==
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Tensorflow Lattice Library.

This package provides functions and classes for lattice modeling.
"""

from __future__ import absolute_import

import tensorflow_lattice.layers

from tensorflow_lattice.python import aggregation_layer
from tensorflow_lattice.python import categorical_calibration_layer
from tensorflow_lattice.python import categorical_calibration_lib
from tensorflow_lattice.python import cdf_layer
from tensorflow_lattice.python import configs
from tensorflow_lattice.python import estimators
from tensorflow_lattice.python import kronecker_factored_lattice_layer
from tensorflow_lattice.python import kronecker_factored_lattice_lib
from tensorflow_lattice.python import lattice_layer
from tensorflow_lattice.python import lattice_lib
from tensorflow_lattice.python import linear_layer
from tensorflow_lattice.python import linear_lib
from tensorflow_lattice.python import model_info
from tensorflow_lattice.python import parallel_combination_layer
from tensorflow_lattice.python import premade
from tensorflow_lattice.python import premade_lib
from tensorflow_lattice.python import pwl_calibration_layer
from tensorflow_lattice.python import pwl_calibration_lib
from tensorflow_lattice.python import pwl_calibration_sonnet_module
from tensorflow_lattice.python import test_utils
from tensorflow_lattice.python import utils
from tensorflow_lattice.python import visualization

import tensorflow_lattice.sonnet_modules

==> tensorflow_lattice-2.0.12-py2.py3-none-any.whl: tensorflow_lattice/__init__.py <==
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Tensorflow Lattice Library.

This package provides functions and classes for lattice modeling.
"""

from __future__ import absolute_import

import tensorflow_lattice.layers
from tensorflow_lattice.python import aggregation_layer
from tensorflow_lattice.python import categorical_calibration_layer
from tensorflow_lattice.python import categorical_calibration_lib
from tensorflow_lattice.python import cdf_layer
from tensorflow_lattice.python import conditional_cdf
from tensorflow_lattice.python import conditional_pwl_calibration
from tensorflow_lattice.python import configs
from tensorflow_lattice.python import estimators
from tensorflow_lattice.python import kronecker_factored_lattice_layer
from tensorflow_lattice.python import kronecker_factored_lattice_lib
from tensorflow_lattice.python import lattice_layer
from tensorflow_lattice.python import lattice_lib
from tensorflow_lattice.python import linear_layer
from tensorflow_lattice.python import linear_lib
from tensorflow_lattice.python import model_info
from tensorflow_lattice.python import parallel_combination_layer
from tensorflow_lattice.python import premade
from tensorflow_lattice.python import premade_lib
from tensorflow_lattice.python import pwl_calibration_layer
from tensorflow_lattice.python import pwl_calibration_lib
from tensorflow_lattice.python import test_utils
from tensorflow_lattice.python import utils
from tensorflow_lattice.python import visualization
